/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.post;

import com.yiring.app.param.post.PostFindParam;
import com.yiring.app.param.post.PostModifyParam;
import com.yiring.app.param.post.PostParam;
import com.yiring.app.vo.post.PostVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import javax.servlet.http.HttpServletResponse;

/**
 * 职位信息
 * @author LJ-2204
 * @date 2022/4/13
 */
public interface PostService {
    /**
     * 新增职位信息
     * @param postParam 入参
     * @return Result<String>
     */
    Result<String> addPost(PostParam postParam);

    /**
     * 修改职位信息
     * @param postParam 入参
     * @return Result<String>
     */
    Result<String> modifyPost(PostModifyParam postParam);

    /**
     * 销毁职位信息
     * @param idParam id
     * @return Result<String>
     */
    Result<String> deletePost(IdParam idParam);

    /**
     * 职位信息分页
     * @param param 入参
     * @return Result<PageVo<PostVo>>
     */
    Result<PageVo<PostVo>> findPostPage(PostFindParam param, PageParam pageParam);

    /**
     * 详细信息查询
     * @param idParam id
     * @return Result<PostVo>
     */
    Result<PostVo> findPostById(IdParam idParam);

    /**
     * 根据名称判断是否存在职业信息
     * @param name 职业名称
     * @return T/F
     */
    boolean hasPostInfo(String name);

    /**
     * 导出职位信息
     * @param param 入参
     * @param response 响应信息
     */
    void exportPostInfo(PostFindParam param, HttpServletResponse response);

    /**
     * 下拉菜单
     * @return Result<PageVo<PostVo>>
     */
    Result<PageVo<PostVo>> selectPost();
}
