/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.user;

import com.yiring.app.param.user.*;
import com.yiring.app.vo.user.UserVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.multipart.MultipartFile;

/**
 * 用户
 * @author LJ-2204
 * @date 2022/4/20
 */
public interface UserService {
    /**
     * 表格查询
     * @param param UserByNameParam
     * @param pageParam PageParam
     * @return Result<PageVo<UserAutoVo>>
     */
    Result<PageVo<UserVo>> findUserPage(UserFindParam param, PageParam pageParam);

    /**
     * 用户详细信息
     * @param idParam IdParam
     * @return Result<UserVo>
     */
    Result<UserVo> findUserById(IdParam idParam);

    /**
     * 用户绑定标签
     * @param param UserBingTagParam
     * @return Result<String>
     */
    Result<String> userBingTag(UserBingTagParam param);

    /**
     * 收卡
     * @param idParam IdParam
     * @return Result<String>
     */
    Result<String> userUnBingTag(IdParam idParam);

    /**
     * 删除用户
     * @param idParam IdParam
     * @return Result<String>
     */
    Result<String> deleteUser(IdParam idParam);

    /**
     * 下拉菜单
     * @return Result<PageVo<UserVo>>
     */
    Result<PageVo<UserVo>> selectUser();

    /**
     * 导出用户
     * @param param UserFindParam
     * @param response HttpServletResponse
     */
    void exportUser(UserFindParam param, HttpServletResponse response);

    /**
     * 启用/停用
     * @param idParam IdParam
     * @return Result<String>
     */
    Result<String> stateUser(IdParam idParam);

    /**
     * 修改用户
     * @param param UserModifyParam
     * @return Result<String>
     */
    Result<String> modifyUser(UserModifyParam param);

    /**
     * 新增用户
     * @param param UserAddParam
     * @return Result<String>
     */
    Result<String> addUser(UserAddParam param);

    /**
     * 导入
     * @param file MultipartFile
     * @return Result<String>
     */
    Result<String> importUser(MultipartFile file);

    /**
     * 用户索引
     * @param param UserIndexParam
     * @return Result<PageVo<UserVo>>
     */
    Result<PageVo<UserVo>> indexUser(UserIndexParam param);
}
