/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.dept;

import com.yiring.app.param.dept.DepartmentAddParam;
import com.yiring.app.param.dept.DepartmentFindParam;
import com.yiring.app.param.dept.DepartmentModifyParam;
import com.yiring.app.service.dept.DepartmentService;
import com.yiring.app.vo.dept.DepartmentInfoVo;
import com.yiring.app.vo.dept.DepartmentVo;
import com.yiring.auth.param.IdsParam;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

/**
 * 部门信息控制器
 * @author LJ-2204
 * @date 2022/4/19
 */

@Slf4j
@Validated
@Api(tags = "部门信息")
@RestController
@RequestMapping("/dept/")
public class DepartmentController {

    @Resource
    DepartmentService departmentService;

    @ApiOperation("新增部门")
    @PostMapping("addDepartment")
    public Result<String> addDepartment(@Valid DepartmentAddParam param) {
        return departmentService.addDepartment(param);
    }

    @ApiOperation("树形表格")
    @GetMapping("findDepartmentTree")
    public Result<PageVo<DepartmentVo>> findDepartmentTree(@Valid DepartmentFindParam param) {
        return departmentService.findDepartmentTree(param);
    }

    @ApiOperation("部门详细信息")
    @GetMapping("findDepartmentInfo")
    public Result<DepartmentInfoVo> findDepartmentInfo(@Valid IdParam idParam) {
        return departmentService.findDepartmentInfo(idParam);
    }

    @ApiOperation("部门导出")
    @GetMapping("exportDepartment")
    public void exportDepartment(@Valid DepartmentFindParam param, HttpServletResponse response) {
        departmentService.exportDepartment(param, response);
    }

    @ApiOperation("逻辑删除部门")
    @DeleteMapping("deleteDepartment")
    public Result<String> deleteDepartment(@Valid IdParam idParam) {
        return departmentService.deleteDepartment(idParam);
    }

    @ApiOperation("启用/停用")
    @PutMapping("stateDepartment")
    public Result<String> stateDepartment(@Valid IdParam idParam) {
        return departmentService.stateDepartment(idParam);
    }

    @ApiOperation("给部门添加职位")
    @PutMapping("deptBingPost")
    public Result<String> deptBingPost(@Valid IdParam idParam, @Valid IdsParam idsParam) {
        return departmentService.deptBingPost(idParam, idsParam);
    }

    @ApiOperation("部门编辑")
    @PutMapping("modifyDepartment")
    public Result<String> modifyDepartment(@Valid DepartmentModifyParam param) {
        return departmentService.modifyDept(param);
    }

    @ApiOperation("部门导入")
    @PostMapping("Department")
    public Result<String> importDepartment(@RequestParam("file") MultipartFile file) {
        return departmentService.importDepartment(file);
    }
}
