/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.post;

import com.yiring.app.param.post.PostFindParam;
import com.yiring.app.param.post.PostModifyParam;
import com.yiring.app.param.post.PostParam;
import com.yiring.app.service.post.PostService;
import com.yiring.app.vo.post.PostVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 职位信息控制器
 * @author LJ-2204
 * @date 2022/4/12
 */

@Slf4j
@Validated
@Api(tags = "职位信息")
@RestController
@RequestMapping("/post/")
public class PostController {

    @Resource
    PostService postService;

    @ApiOperation(value = "新增职位")
    @PostMapping("addPost")
    public Result<String> addPost(@Valid PostParam postParam) {
        return postService.addPost(postParam);
    }

    @ApiOperation(value = "修改职位")
    @PutMapping("modifyPost")
    public Result<String> modifyPost(@Valid PostModifyParam postParam) {
        return postService.modifyPost(postParam);
    }

    @ApiOperation(value = "销毁职位")
    @DeleteMapping("deletePost")
    public Result<String> deletePost(@Valid IdParam idParam) {
        return postService.deletePost(idParam);
    }

    @ApiOperation(value = "分页查询")
    @GetMapping("findPostPage")
    public Result<PageVo<PostVo>> findPostPage(@Valid PostFindParam param, @Valid PageParam pageParam) {
        return postService.findPostPage(param, pageParam);
    }

    @ApiOperation(value = "详细信息查询")
    @GetMapping("findPostById")
    public Result<PostVo> findPostById(@Valid IdParam idParam) {
        return postService.findPostById(idParam);
    }

    @ApiOperation(value = "导出职位信息")
    @GetMapping("exportPostInfo")
    public void exportPostInfo(@Valid PostFindParam param, HttpServletResponse response) {
        postService.exportPostInfo(param, response);
    }

    @ApiOperation(value = "下拉菜单")
    @GetMapping("selectPost")
    public Result<PageVo<PostVo>> selectPost() {
        return postService.selectPost();
    }
}
