/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.user;

import com.yiring.app.param.user.*;
import com.yiring.app.service.user.UserService;
import com.yiring.app.vo.user.UserVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

/**
 * 用户信息
 *
 * @author Jim
 * @version 0.1
 * 2022/1/24 14:13
 */

@Slf4j
@Validated
@Api(tags = "人员管理")
@RestController
@RequestMapping("/user/app/")
public class UserAppController {

    @Resource
    UserService userService;

    @ApiOperation("表格查询")
    @GetMapping("findUserPage")
    public Result<PageVo<UserVo>> findUserPage(@Valid UserFindParam param, @Valid PageParam pageParam) {
        return userService.findUserPage(param, pageParam);
    }

    @ApiOperation("用户详细信息查询")
    @GetMapping("findUserById")
    public Result<UserVo> findUserById(@Valid IdParam idParam) {
        return userService.findUserById(idParam);
    }

    @ApiOperation("给用户分配标签卡")
    @PutMapping("userBingTag")
    public Result<String> userBingTag(@Valid UserBingTagParam param) {
        return userService.userBingTag(param);
    }

    @ApiOperation("收卡")
    @PutMapping("userUnBingTag")
    public Result<String> userUnBingTag(@Valid IdParam idParam) {
        return userService.userUnBingTag(idParam);
    }

    @ApiOperation("逻辑删除用户")
    @DeleteMapping("deleteUser")
    public Result<String> deleteUser(@Valid IdParam idParam) {
        return userService.deleteUser(idParam);
    }

    @ApiOperation("下拉菜单")
    @GetMapping("selectUser")
    public Result<PageVo<UserVo>> selectUser() {
        return userService.selectUser();
    }

    @ApiOperation("用户导出")
    @GetMapping("exportUser")
    public void exportUser(@Valid UserFindParam param, HttpServletResponse response) {
        userService.exportUser(param, response);
    }

    @ApiOperation("启用/停用")
    @PutMapping("stateUser")
    public Result<String> stateUser(@Valid IdParam idParam) {
        return userService.stateUser(idParam);
    }

    @ApiOperation("编辑用户")
    @PutMapping("modifyUser")
    public Result<String> modifyUser(@Valid UserModifyParam param) {
        return userService.modifyUser(param);
    }

    @ApiOperation("新增用户")
    @PostMapping("addUser")
    public Result<String> addUser(@Valid UserAddParam param) {
        return userService.addUser(param);
    }

    @ApiOperation("导入")
    @PostMapping("importUser")
    public Result<String> importUser(@RequestParam("file") MultipartFile file) {
        return userService.importUser(file);
    }

    @ApiOperation("用户信息检索")
    @GetMapping("indexUser")
    public Result<PageVo<UserVo>> indexUser(@Valid UserIndexParam param) {
        return userService.indexUser(param);
    }
}
